@@ -1,12 +1,12 @@
 /* This code is derived from the Linux Kernel sources intended
  * to maintain compatibility with different Kernel versions.
  * Copyright of original source is of respective Linux Kernel authors.
- * License is GPLv2.
+ * License is GPL-2.0-only.
  */
 
 #ifndef COMPAT_NETFLOW_H
 #define COMPAT_NETFLOW_H
-
+#include "compat_def.h"
 
 #ifndef NIPQUAD
 # define NIPQUAD(addr) \
@@ -212,6 +212,22 @@ err:
 #define num_physpages	totalram_pages
 #endif
 
+#ifndef HAVE_TIMEVAL
+/* timeval is only used internally, so we can use anything for it. */
+struct timeval {
+	long tv_sec;
+	long tv_usec; /* microseconds */
+};
+
+unsigned long timeval_to_jiffies(const struct timeval *tv)
+{
+	return timespec64_to_jiffies(&(struct timespec64){
+				     tv->tv_sec,
+				     tv->tv_usec * NSEC_PER_USEC
+				     });
+}
+#endif
+
 #if LINUX_VERSION_CODE < KERNEL_VERSION(2,6,35)
 # ifdef ktime_to_timeval
 /* ktime_to_timeval is defined on 64bit and inline on 32bit cpu */
@@ -612,7 +628,7 @@ out:
 #endif
 
 /* Offset changes made in 613dbd95723aee7abd16860745691b6c7bda20dc */
-#if LINUX_VERSION_CODE >= KERNEL_VERSION(2,6,28) && LINUX_VERSION_CODE < KERNEL_VERSION(4,10,0)
+#ifndef HAVE_XT_FAMILY
 # if LINUX_VERSION_CODE < KERNEL_VERSION(2,6,35)
 #  define xt_action_param xt_target_param
 # endif
@@ -680,11 +696,13 @@ static inline int is_vlan_dev(struct net_device *dev)
 #endif
 
 #if LINUX_VERSION_CODE < KERNEL_VERSION(5,0,0)
+# ifdef CONFIG_BRIDGE_NETFILTER
 static inline struct nf_bridge_info *
 nf_bridge_info_get(const struct sk_buff *skb)
 {
 	return skb->nf_bridge;
 }
+# endif
 #endif
 
 #if LINUX_VERSION_CODE >= KERNEL_VERSION(5,0,0)
